function coeffs(vmecSurface::VmecSurface, s::Float64, init_zeta::Float64, init_theta::Float64, 
                npt::Int64, coeff_data::coeffs_struct, params::BalloonParams)
  
  b2 = zeros(npt);
  c2 = zeros(npt);
  k_s = zeros(npt);
  bsuppar = zeros(npt);

  lfail_balloon = summodosd(vmecSurface, init_zeta, init_theta, npt, coeff_data.x, c2, k_s, bsuppar, b2);
  if lfail_balloon
     return lfail_balloon
  end

  phipc = vmecSurface.phi[2]/(-2*π) #phi derivative

  b2n = b2 ./ (params.b0_v^2);                    # magnetic field normalized to B_0
  bsupparn = params.r0*bsuppar ./ params.b0_v;
  c2n = c2 .* (params.amin^2);                    # perpend. wave vector squared
  μ0 = 4*π*1.0e-7
  prespn = 2*vmecSurface.pres[2]*μ0/(params.beta0*params.b0_v^2);     # pressure normalized to p_0
  phipn2 = (phipc/(params.b0_v*params.amin^2))^2;      # perpend. lengths normalized to a
  eps2 = (params.r0/params.amin)^2;
  factor = eps2*params.beta0*prespn/phipn2;

  # P, Q and R:  ballooning coefficients

  coeff_data.p .= bsupparn .* c2n ./ b2n;
  coeff_data.q .= factor .* k_s ./ bsupparn;
  coeff_data.r .= c2n ./ (b2n .* bsupparn);

  #debugging
  #zetang = init_zeta .+ coeff_data.x;
  #for i in 1:length(coeff_data.p)
  #  println("coeffs: ",zetang[i]," ",coeff_data.p[i]," ",coeff_data.q[i]," ",coeff_data.r[i])
  #end

  return lfail_balloon
end
