function get_ballooning_grate(vmecSurface::VmecSurface, 
                              init_zeta::Float64, init_theta::Float64,
                             params::BalloonParams)
  # Frequently used values as local variables
  np0_in = 793;   # coarsest grid used in Richardson's loop
  lmax = 3;      # Maximum number of Richardson loops
  krich = 3;      # Number of steps used for extrapolation
  km = krich - 1;
  tole = 1e-3; 
  #none of the above parameters are really used, besides np0_in
  s = vmecSurface.s
#------------------------------------------
#       BEGIN MIGRATION TO FULL MESH


  # create full mesh magnetic field tuple, add to coords tuple

  fullp = 2*π/vmecSurface.nfp;
  semip = fullp/2;

  # Check for stellarator symmetry

  tsymm = false;          # Assume no symmetry about x = 0 on the field line
  if !vmecSurface.lasym
    if (params.l_geom_input &&
       ((init_zeta == 0 || init_zeta == semip || init_zeta == fullp) &&
        init_theta == 0))
        tsymm = true;
    end
    if (!params.l_geom_input && !params.l_tokamak_input &&
       (init_zeta == 0 && init_theta == 0)) # here, init_zeta is init_zetak_st and init_theta is init_alpha_st
       tsymm = true;
    end
  end

#      END OF MIGRATION TO FULL MESH
#------------------------------------------

#------------------------------------------
#          BEGIN BALLOONING LOOP

  hv = [1; zeros(lmax)];
  eigv = zeros(lmax);
  l_success = false;

  #Calculate limits of integration
  #
  #
  # account for K_w potential wells###
  xmax = π*(2*params.k_w - 1) ./ (2*vmecSurface.nfp*vmecSurface.iota[1])
  if tsymm
    xmin = 0.0;
    np  = Int(6 * floor(np0_in / 12) + 1);     # number of points always odd and multiple of 3; half in symmetric case
    h   = xmax/(np-1);
    inc  = 1;                         # solution vector includes F(0)
  else
    np  = Int(6 * floor(np0_in / 6) + 1);      # number of points always odd and multiple of 3
    xmin = -xmax;
    h   = 2*(xmax/(np - 1));
    inc  = 0;                         # solution vector does not include f(0) since f(0)=0.
  end
  npm1 = np - 1;
  npm2 = np - 2;
  npm3 = np - 3;
#      END OF MIGRATION TO FULL MESH
#------------------------------------------

  #------------------------------------------
  #         BEGIN RICHARDSON'S LOOP

  # Create vectors for coefficients and diagonals
  coeffs_f = coeffs_struct(zeros(np), zeros(np), zeros(np), zeros(np))
  coeffs_h = coeffs_struct(zeros(npm1), zeros(npm1), zeros(npm1), zeros(npm1));
  diagonals = diagonal_struct(zeros(npm2 + inc), zeros(npm3 + inc), zeros(npm3 + inc));




  lfail_balloon = getmatrix(vmecSurface, s, init_zeta, init_theta, inc, xmin, 
                                h, np, tsymm, coeffs_f, coeffs_h, diagonals, params);

  if lfail_balloon      # if theta does not converge in getmatrix/coeffs/summodosd/get_theta
    growthRate = NaN;
    return
  end
    #println("lfail_balloon ",lfail_balloon)

  lfail_balloon, eigm = geteigm(npm2+inc, diagonals); # only need eigenfunction
  if lfail_balloon      # if matrix is not positive definite
    growthRate = NaN;
  return
  end
    #println("lfail_balloon2 ",lfail_balloon)

#  println("eigm: ",eigm)
  if eigm < 0
    growthRate = -sqrt(-eigm);
  else
    growthRate = sqrt(eigm);
  end
  return growthRate, xmax, np, 1, tsymm

    #          END RICHARDSON'S LOOP
    #------------------------------------------


#     END BALLOONING LOOP
#------------------------------------------


end
